# worldnewsapi
The World News API gives you access to thousands of news sources in over 50 languages from over 150 countries. News are semantically tagged allowing for semantic news search like never before.

This is the python-package for easy acccess to the api.

## Resources

- [Homepage](https://worldnewsapi.com/)
- [Tutorial](https://worldnewsapi.com/docs/#Tutorial-Getting-Started)
- [Full API Documentation](https://github.com/ddsky/world-news-api-clients/blob/main/python/README.md)

## Requirements

Python 3.7+

## Installation & Usage
### pip install

This package is hosted on PyPi, you can install directly using:

```sh
pip install worldnewsapi
```
(you may need to run `pip` with root permission: `sudo pip install worldnewsapi`)

Then import the package:
```python
import worldnewsapi
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import worldnewsapi
```

### Tests

Execute `pytest` to run the tests.

